@@ -16,10 +16,13 @@ use Carp qw( croak );
 use Net::SSH::Perl::Auth;
 use base qw( Net::SSH::Perl::Auth );
 
+use Scalar::Util qw(weaken);
+
 sub new {
     my $class = shift;
     my $ssh = shift;
     my $auth = bless { ssh => $ssh }, $class;
+    weaken $auth->{ssh};
     $auth->enabled( $ssh->config->get('auth_kbd_interactive') &&
                     $ssh->config->get('interactive') );
     $auth;
